# Public APIs

A collective list of JSON APIs for use in web development.

> While I appreciate the masses of pull requests and community involvement, some PRs have been specifically to market company APIs that offer paid for solutions. This API list is not a marketing tool, but a tool to help the community build applications and use free public APIs quickly and easily. Pull requests that explicitly are marketing attempts won't be accepted, thanks for understanding! :)

### Animals

| API | Description | OAuth | Link |
|---|---|---|---|
| IUCN | IUCN Red List of Threatened Species | No, but a token is required | [Go!](http://apiv3.iucnredlist.org/api/v3/docs) |
| Petfinder | Adoption | No | [Go!](https://www.petfinder.com/developers/api-docs/) |
| RescueGroups | Adoption | No | [Go!](https://userguide.rescuegroups.org/display/APIDG/API+Developers+Guide+Home) |

### Anime

| API | Description | OAuth | Link |
|---|---|---|---|
| AniList | AniList Anime API | Yes | [Go!](http://anilist-api.readthedocs.org/en/latest/#) |
| Hummingbird | Hummingbird Anime API | No | [Go!](https://hummingbird.me/) |

### Anti-Malware

| API | Description | OAuth | Link |
|---|---|---|---|
| Certly | Certly Link/Domain Flagging API | No, but a token is required | [Go!](https://guard.certly.io/) |
| Google Safe Browsing | Google Link/Domain Flagging API | No, but a token is required | [Go!](https://developers.google.com/safe-browsing/) |
| Metacert | Metacert Link Flagging API | No, but a token is required | [Go!](https://metacert.com/) |
| VirusTotal | VirusTotal File/URL Analysis API | No, but a token is required | [Go!](https://www.virustotal.com/en/documentation/public-api/) |
| Web Of Trust (WOT) | Website reputation API | No, but `key` string | [Go!](https://www.mywot.com/wiki/API) |

### Art & Design

| API | Description | OAuth | Link |
|---|---|---|---|
| Dribbble | Design | Yes | [Go!](http://developer.dribbble.com/v1/) |
| Noun Project | Icons | Yes | [Go!](http://api.thenounproject.com/index.html) |
| Rijksmuseum| Art | No | [Go!](https://www.rijksmuseum.nl/en/api) |

### Books

| API | Description | OAuth | Link |
|---|---|---|---|
| British National Bibliography | Books | No | [Go!](http://bnb.data.bl.uk/) |
| Good Reads | Books | No | [Go!](https://www.goodreads.com/api) |
| Google Books | Books | Yes | [Go!](https://developers.google.com/books/)

### Business

| API | Description | OAuth | Link |
|---|---|---|---|
| markerapi | Trademark Search API | No | [Go!](http://www.markerapi.com/) |

### Calendar

| API | Description | OAuth | Link |
|---|---|---|---|
| Church Calendar API | Catholic liturgical calendar | No | [Go!](http://calapi.inadiutorium.cz/) |
| Date and Time | Global Date and Time | No | [Go!](http://www.timeanddate.com/services/api/) |
| Holidays | Free API for obtaining information about holidays. | No | [Go!](http://holidayapi.com/) |
| Non-working days API | Database of ICS files for non working days | No | [Go!](https://github.com/gadael/icsdb) |

### Development

| API | Description | OAuth | Link |
|---|---|---|---|
| Adorable Avatars | Generate random cartoon avatars | No | [Go!](http://avatars.adorable.io) |
| APIs.guru | Wikipedia for Web APIs, OpenAPI/Swagger specs for public APIs | No | [Go!] (https://apis.guru/api-doc/) |
| CDNJS | Library info on CDNJS | No | [Go!](https://api.cdnjs.com/libraries/jquery) |
| Faceplusplus | A tool to detect face | Yes | [Go!](http://www.faceplusplus.com/uc_home/) |
| Github - User Data | Pull public information for a user's github | No | [Go!](https://api.github.com/users/hackeryou) |
| Gitter | Chat for GitHub | Yes | [Go!](https://developer.gitter.im/docs/) |
| Hipster Ipsum | Generates Hipster Ipsum text | No | [Go!](http://hipsterjesus.com/)
| JSONPlaceholder | Fake data for testing and prototyping | No | [Go!](http://jsonplaceholder.typicode.com/) |
| LiveCoding | Live Coding Streaming API | Yes | [Go!](https://www.livecoding.tv/developer/applications/)
| Lorem Text | Generates Lorem Ipsum text | No, but requires `X-Mashape-Key` as header | [Go!](https://market.mashape.com/montanaflynn/lorem-text-generator)
| Loripsum | The "lorem ipsum" generator that doesn't suck | No | [Go!](http://loripsum.net/)
| Plino | Spam filtering system | No | [Go!](https://plino.herokuapp.com/) |
| Random Word | Generate random word | No | [Go!](http://randomword.setgetgo.com/) |
| RandomUser | Generates random user data | No | [Go!](https://randomuser.me) |
| ReqRes | A hosted REST-API ready to respond to your AJAX requests | No | [Go!](http://reqres.in/)
| RoboHash | Generate random robot/alien avatars | No | [Go!](https://robohash.org/) |
| StackExchange | The All-in-one API for StackExchange sites | Yes | [Go!](https://api.stackexchange.com/)
| UI Faces | Find and generate sample avatars for user interfaces | No | [Go!](http://uifaces.com/api) |
| UI Names | Generate random fake names | No | [Go!](https://github.com/thm/uinames) |

### Documents & Productivity

| API | Description | OAuth |Link |
|---|---|---|---|
| File.io | Files | No | [Go!](https://file.io) |
| pdflayer API | HTML/URL to PDF | No | [Go!](https://pdflayer.com) |

### Drinks

| API | Description | OAuth | Link |
|---|---|---|---|
| BreweryDB | Beer | No, but `apiKey` query string |[Go!](http://www.brewerydb.com/developers) |
| LCBO API | Alcohol | No, but `apiKey` query string |[Go!](https://lcboapi.com/) |
| PunkAPI | Brewdog Beer Recipes | No | [Go!](https://punkapi.com/) |
| Recipe Puppy | Food | No | [Go!](http://www.recipepuppy.com/about/api/)
| Yummly | Find food recipes | No | [Go!](https://developer.yummly.com/) |

### Data Access

| API | Description | OAuth | Link |
|---|---|---|---|
| 18F | US Federal Government /Developer Program | No | [Go!](http://18f.github.io/API-All-the-X/) |
| Abbreviation API | Get abbreviations and meanings | No, but requires `X-Mashape-Key` as header |[Go!](https://market.mashape.com/daxeel/abbreviations) |
| Callook.info API | United States ham radio callsigns | No |[Go!](https://callook.info) |
| Celebinfo API | Celebrity information API | No, but requires `X-Mashape-Key` as header |[Go!](https://market.mashape.com/daxeel/celebinfo/) |
| Colorado Data Engine | Formatted and geolocated Colorado public data | No |[Go!](http://codataengine.org/) |
| Colorado Information Marketplace | Colorado State Government Open Data | No |[Go!](https://data.colorado.gov/) |
| Data USA | US Public Data | No |[Go!](http://datausa.io/about/api/) |
| Dronestream API | Tracks United States drone strikes | No |[Go!](http://dronestre.am/) |
| fonoApi | Mobile Device Description | No |[Go!](https://fonoapi.freshpixl.com/) |
| Open Government, Australia | Australian Government Open Data | No |[Go!](https://www.data.gov.au/) |
| Open Government, USA | United States Government Open Data | No |[Go!](https://www.data.gov/) |
| Open Government, Canada | Canadian Government Open Data | No |[Go!](http://open.canada.ca/en) |
| Quandl API | Stock Market Data | No |[Go!](https://www.quandl.com/) |
| Wikipedia | Mediawiki API | No |[Go!](https://www.mediawiki.org/wiki/API:Main_page) |
| Wordnik | Dictionary Data API | No | [Go!](http://developer.wordnik.com) |
| Yelp | Find Local Business | Yes |[Go!](https://www.yelp.com/developers) |

### Data Validation

| API | Description | OAuth |Link |
|---|---|---|---|
| languagelayer API | Language detection | No | [Go!](https://languagelayer.com) |
| mailboxlayer API | Email address validation | No | [Go!](https://mailboxlayer.com) |
| numverify API | Phone number validation | No | [Go!](https://numverify.com) |
| vatlayer API | VAT number validation | No | [Go!](https://vatlayer.com) |

### Environment

| API | Description | OAuth | Link |
|---|---|---|---|
| PM2.5.in | PM2.5 Data of China | No, but apiKey query string | [Go!](http://www.pm25.in/api_doc) |

### Exchange

| API | Description | OAuth | Link |
|---|---|---|---|
| Currencylayer | Exchange rates and currency conversion | No, but `apiKey` query string | [Go!](https://currencylayer.com/documentation) |
| Fixer.io | JSON API for foreign exchange rates and currency conversion | No | [Go!](http://fixer.io) |

### Games & Comics

| API | Description | OAuth | Link |
|---|---|---|---|
| Battle.net | Blizzard API | No | [Go!](https://dev.battle.net/)  |
| Chuck Norris Database | Jokes | No | [Go!](http://www.icndb.com/api) |
| Clash of Clans | Clash of Clans API | No | [Go!](https://developer.clashofclans.com) |
| ClashAPI | Clash Royale API | No | [Go!](https://github.com/martincarrera/clash-royale-api)  |
| Comic Vine | Comics | No | [Go!](http://comicvine.gamespot.com/api/documentation) |
| Deck of Cards | Deck of Cards API | No | [Go!](http://deckofcardsapi.com/)  |
| Eve Online | Third-Party Developer Documentation API | Parts | [Go!](https://eveonline-third-party-documentation.readthedocs.io/en/latest/)  |
| Giant Bomb | Video Games | No |[Go!](http://www.giantbomb.com/api/documentation) |
| Guild Wars 2 | Guild Wars 2 API | No, but `apiKey` query string (for some routes) | [Go!](https://wiki.guildwars2.com/wiki/API:Main) |
| Magic the gathering | Magic the gathering API | No | [Go!](http://magicthegathering.io/)  |
| Marvel | Marvel Comics API | No | [Go!](http://developer.marvel.com) |
| Minecraft | Minecraft API (For server info & user info) | No |[Go!](https://mcapi.ca/) |
| Pokéapi | The RESTful Pokémon API | No |[Go!](http://pokeapi.co) |
| Riot Games | The RESTful League of Legends API | No |[Go!](https://developer.riotgames.com/) |
| Steam | Steam Client API | Yes | [Go!](https://developer.valvesoftware.com/wiki/Steam_Web_API) |
| SWAPI | Star Wars API | No |[Go!](https://swapi.co) |

### Geocoding

| API | Description | OAuth | Link |
|---|---|---|---|
| GeoNames | Place names and other geographical data | No | [Go!](http://www.geonames.org/export/web-services.html) |
| Google Maps API | Create/customize digital maps based on Google Maps data | No, but `apiKey` query string | [Go!](https://developers.google.com/maps/) |
| IP 2 Country | Map an IP to a country | No | [Go!](https://ip2country.info) |
| IP Address Details| Find geolocation with ip address | No | [Go!](https://ipinfo.io/) |
| Mapbox | Create/customize beautiful digital maps | No, but `apiKey` query string | [Go!](https://www.mapbox.com/developers/) |
| Mapzen Search | Open Source & Open Data Global Geocoding Service | No | [Go!](https://mapzen.com/projects/search) |
| Mexico | Mexico RESTful zip codes API | No | [Go!](https://github.com/IcaliaLabs/sepomex) |
| OpenCage | Forward and reverse geocoding using open data | No | [Go!](https://geocoder.opencagedata.com) |
| OpenStreetMap | Navigation, geolocation and geographical data | Yes | [Go!](http://wiki.openstreetmap.org/wiki/API) |
| PostcodeData.nl | Provide geolocation data based on postcode for Dutch addresses | No | [Go!](http://api.postcodedata.nl/v1/postcode/?postcode=1211EP&streetnumber=60&ref=domeinnaam.nl&type=json) |
| Postcodes.io | Postcode & Geolocation API for the UK | No | [Go!](https://postcodes.io) |

### Health

| API | Description | OAuth | Link |
|---|---|---|---|
| USDA Nutrients | National Nutrient Database for Standard Reference | No | [Go!](https://ndb.nal.usda.gov/ndb/doc/index) |
| Nutritionix | Worlds largest verified nutrition database | No, but `apiKey` query string | [Go!](https://developer.nutritionix.com/) |

### Music

| API | Description | OAuth | Link |
|---|---|---|---|
| Deezer | Music | Yes | [Go!](http://developers.deezer.com/api) |
| Discogs | Music | No | [Go!](https://www.discogs.com/developers/) |
| EchoNest | Music | No | [Go!](http://developer.echonest.com/docs/v4) |
| Genius | Crowdsourced lyrics and music knowledge | Yes | [Go!](https://docs.genius.com/)
| Jamendo | Music | Yes | [Go!](https://developer.jamendo.com/v3.0) |
| iTunes Search | Software products API | No | [Go!](https://affiliate.itunes.apple.com/resources/documentation/itunes-store-web-service-search-api/) |
| LastFm | Music | No | [Go!](http://www.last.fm/api) |
| Mixcloud | Music | No | [Go!](https://www.mixcloud.com/developers/) |
| MusicBrainz | Music | No | [Go!](https://musicbrainz.org/doc/Development/XML_Web_Service/Version_2) |
| Musikki | Music | No | [Go!](https://music-api.musikki.com/reference) |
| Musixmatch | Music | No, but `apikey` query string | [Go!](https://developer.musixmatch.com/) |
| Songsterr | Provides guitar, bass and drums tabs and chords  | No | [Go!](https://www.songsterr.com/a/wa/api/) |
| Soundcloud | Music | No | [Go!](https://developers.soundcloud.com/) |
| Spotify | Music | Parts | [Go!](https://developer.spotify.com/web-api/) |

### Open Source projects

| API | Description | OAuth | Link |
|---|---|---|---|
| Countly  | Countly web analytics API | No | [Go!](http://resources.count.ly/) |
| Drupal.org | Drupal.org API | No | [Go!](https://www.drupal.org/drupalorg/api) |
| Libraries.io | Open source software libraries | No, but `apiKey` query string | [Go!](https://libraries.io/api) |

### Personality

| API | Description | OAuth | Link |
|---|---|---|---|
| Forismatic | Inspirational Quotes | No | [Go!](http://forismatic.com/en/api/) |
| Medium | Community of readers and writers offering unique perspectives on ideas. | Yes | [Go!](https://github.com/Medium/medium-api-docs)
| Traitify | Assess, collect, and analyze Personality | No | [Go!](https://developer.traitify.com/) |

### Photography

| API | Description | OAuth | Link |
|---|---|---|---|
| 500px |  Photography Community | Yes | [Go!](https://github.com/500px/api-documentation)
| Flickr | Flickr Services | Yes | [Go!](https://www.flickr.com/services/api/) |
| Giphy | Get all your gifs | No | [Go!](https://github.com/Giphy/GiphyAPI) |
| Imgur | Images | Yes | [Go!](https://api.imgur.com/#overview) |
| screenshotlayer API | URL 2 Image | No | [Go!](https://screenshotlayer.com) |
| Unsplash | Photography | Yes | [Go!](https://unsplash.com/developers) |

### Planets

| API | Description | OAuth | Link |
|---|---|---|---|
| Minor Planet Center | Asterank.com API | No | [Go!](http://www.asterank.com/mpc) |

### Science

| API | Description | OAuth | Link |
|---|---|---|---|
| Fedger.io | Query machine intelligence data | No | [Go!](https://dev.fedger.io/docs/) |
| inspirehep.net | High Energy Physics info. system | No | [Go!](https://inspirehep.net/info/hep/api?ln=en) |
| NASA | NASA data, including imagery | No | [Go!](https://api.nasa.gov) |
| Open Notify | ISS astronauts, current location API | No | [Go!](http://open-notify.org/Open-Notify-API/) |
| Sunrise and Sunset | Sunset and sunrise times for a given latitude and longitude. | No | [Go!](http://sunrise-sunset.org/api) |
| USGS Earthquake Hazards Program | Earthquakes data real-time | No | [Go!](http://earthquake.usgs.gov/fdsnws/event/1/) |
| World Bank | World Data | No | [Go!](http://data.worldbank.org/developers) |

### Security

| API | Description | OAuth | Link |
|---|---|---|---|
| AXFR Database | AXFR public database API | No | [Go'](http://api.axfrcheck.com) |
| UK Police | UK Police data | No | [Go!](https://data.police.uk/docs/) |

### Social

| API | Description | OAuth | Link |
|---|---|---|---|
| Discord bot API | Make bots for Discord | Yes | [Go!](https://discordapp.com/developers/docs/intro) |
| Facebook API | Facebook Login, Share on FB, Social Plugins, Analytics and more | Yes | [Go!](https://developers.facebook.com/) |
| Fuck Off as a Service | Asks someone to fuck off | No | [Go!](https://www.foaas.com) |
| Full Contact | Get Social Media profiles and contact Information | Yes | [Go!](https://www.fullcontact.com/developer/docs/) |
| HackerNews | Social news for CS and entrepreneurship | No | [Go!](https://github.com/HackerNews/API)
| Instagram API | Instagram Login, Share on Instagram, Social Plugins and more | Yes | [Go!](https://www.instagram.com/developer/) |
| LinkedIn REST-API | The foundation of all digital integrations with LinkedIn | Yes | [Go!](https://developer.linkedin.com/docs/rest-api) |
| Telegram MTProto API | Read and write Telegram data | Yes | [Go!](https://core.telegram.org/api#getting-started) |
| Telegram bot API | Simplified HTTP version of the MTProto API for bots | Yes | [Go!](https://core.telegram.org/bots/api) |
| PWRTelegram bot API | Boosted version of the Telegram bot API | Yes | [Go!](https://pwrtelegram.xyz) |
| Reddit | Homepage of the internet | Parts | [Go!](https://www.reddit.com/dev/api)
| Tumblr API | Read and write Tumblr Data | Yes | [Go!](https://www.tumblr.com/docs/en/api/v2) |
| Twitch | Game Streaming API | Yes | [Go!](https://github.com/justintv/Twitch-API) |
| Twitter API | Read and write Twitter data | Yes | [Go!](https://dev.twitter.com/rest/public) |
| vk API | Read and write vk dat | Yes | [Go!](https://vk.com/dev/sites) |
| Wit.ai API | Turn speech and text into actionable data | Yes | [Go!](https://wit.ai/docs) |

### Sports/Fitness

| API | Description | OAuth | Link |
|---|---|---|---|
| City Bikes API | City Bikes around the world | No | [Go!](http://api.citybik.es/v2/) |
| Ergast F1 API | F1 data from the beginning of the world championships in 1950 | No | [Go!](http://ergast.com/mrd/)
| FitBit | FitBit API | No | [Go!](https://dev.fitbit.com) |
| Football-Data.org | Football Data | No | [Go!](http://api.football-data.org) |
| JCDecaux Bike API | JCDecaux's self-service bicycles | No, but `apiKey` query string | [Go!](https://developer.jcdecaux.com/) |
| Cricket Live Scores | live-score | No, but requires `X-Mashape-Key` as header | [Go!](https://market.mashape.com/dev132/cricket-live-scores) |
| NFL Arrests | NFL Arrest Data | No | [Go!](http://nflarrest.com/api/) |
| Pro Motocross API | The RESTful AMA Pro Motocross lap times for every racer on the start gate | No | [Go!](http://promotocrossapi.com) |
| Stattleship | MLB, NBA, NHL, NFL | No, but a token is required | [Go!](https://www.stattleship.com/#) |
| Strava API | Connect with athletes, activities and more | [Yes](https://strava.github.io/api/v3/oauth/)| [Go!](https://strava.github.io/api/)|
| wger API | Workout manager data as exercises, muscles or equipments | No, but `apiKey` query string | [Go!](https://wger.de/en/software/api) |

### Transportation

| API | Description | OAuth | Link |
|---|---|---|---|
| Amadeus Travel Innovation Sandbox | Travel Search - Limited usage | No, but `apikey` query string | [Go!](https://sandbox.amadeus.com/) |
| Community Transit | Transitland API | No | [Go!](https://github.com/transitland/transitland-datastore/blob/master/README.md#api-endpoints) |
| Goibibo | API for travel search  | No, but `apiKey` query string | [Go!](https://developer.goibibo.com/docs) |
| Indian Railways | Indian Railways API | No, but a token is required |[Go!](http://api.erail.in/) |
| The Nomad List | A list of the best places to live/work remotely | No | [Go!](https://nomadlist.com/faq) |
| Schiphol Airport API | Schiphol | Yes | [Go!](https://flight-info.3scale.net/) |
| TransitLand | Transit Aggregation | No | [Go!](https://transit.land/documentation/datastore/api-endpoints.html)
| Transport for Atlanta, US | Marta | No | [Go!](http://www.itsmarta.com/developers/data-sources/marta-bus-realtime-restful-api.aspx) |
| Transport for Belgium | Belgian transport API | No | [Go!](https://hello.irail.be/api/) |
| Transport for Boston, MA, USA | MBTA API | No | [Go!](http://realtime.mbta.com/Portal/Home/Documents)
| Transport for Budapest | Budapest public transport API | No | [Go!](http://docs.bkkfutar.apiary.io/) |
| Transport for Chicago, US | CTA | No | [Go!](http://www.transitchicago.com/developers/) |
| Transport for Czech Republic | Czech transport API | No | [Go!](http://www.chaps.cz/eng/products/idos-internet) |
| Transport for Finland | Finnish transport API | No | [Go!](http://digitransit.fi/en/developers/) |
| Transport for Germany | Deutsche Bahn (DB) API | No, but `authKey` query string | [Go!](http://data.deutschebahn.com/apis/fahrplan/) |
| Transport for Berlin | third-party VBB API | No | [Go!](https://github.com/derhuerst/vbb-rest/blob/master/docs/index.md) |
| Transport for India | India Public Transport API | No, Api key is required   | [Go!](https://data.gov.in/sector/transport) |
| Transport for London, England | TfL API | No | [Go!](https://api.tfl.gov.uk) |
| Transport for Minneapolis, US | NexTrip API | Yes | [Go!](http://svc.metrotransit.org/) |
| Transport for New York City | MTA | No, but an api key is mandatory | [Go!](http://datamine.mta.info/) |
| Transport for Norway | Norwegian transport API | No | [Go!](http://reisapi.ruter.no/help) |
| Transport for Ottawa, Canada | OC Transpo next bus arrival API | No | [Go!](http://www.octranspo1.com/developers) |
| Transport for Paris, France | RATP Open Data API | No | [Go!](http://data.ratp.fr/api/v1/console/datasets/1.0/search/) |
| Transport for Philadelphia | SEPTA APIs | No | [Go!](http://www3.septa.org/hackathon/) |
| Transport for Rio de Janeiro, Brazil | Prefeitura do Rio (City Hall) | No | [Go!](http://data.rio/group/transporte-e-mobilidade) |
| Transport for Sweden | Public Transport consumer | Yes | [Go!](https://www.trafiklab.se/api) |
| Transport for Switzerland | Swiss public transport API | No | [Go!](https://transport.opendata.ch/) |
| Transport for São Paulo, Brazil | SPTrans | Yes | [Go!](http://www.sptrans.com.br/desenvolvedores/APIOlhoVivo/Documentacao.aspx) |
| Transport for The Netherlands | NS | No | [Go!](http://www.ns.nl/reisinformatie/ns-api) |
| Transport for Tokyo, Japan | Tokyo Metro | No, but apiKey query string |[Go!](https://developer.tokyometroapp.jp/)  |
| Transport for Toronto, Canada | TTC | No| [Go!](https://myttc.ca/developers) |
| Transport for Vancouver, Canada | TransLink | Yes | [Go!](https://developer.translink.ca/) |
| Transport for Washington, US | Washington Metro transport API | Yes | [Go!](https://developer.wmata.com/) |
| Transport for Madrid, Spain | Madrid BUS transport API | No, but apiKey query string |[Go!](http://opendata.emtmadrid.es/Servicios-web/BUS) |
| Transport for Auckland, New Zealand | Auckland Transport API  | No | [Go!](https://api.at.govt.nz/) |

### University

| API | Description | OAuth | Link |
|---|---|---|---|
| University API | University names, countries and domains| No| [Go!](https://github.com/Hipo/university-domains-list) |

### Vehicle

| API | Description | OAuth | Link |
|---|---|---|---|
| Vehicle API | Lot of vehicles informations | No, but `apiKey` query string | [Go!](http://developer.edmunds.com/api-documentation/overview/) |

### Video

| API | Description | OAuth | Link |
|---|---|---|---|
| An API of Ice And Fire | Game Of Thrones API | No | [Go!](https://anapioficeandfire.com/) |
| Dailymotion | Dailymotion Developer API | Yes / No | [Go!](https://developer.dailymotion.com/) |
| MovieDB | Movie Data | No | [Go!](https://www.themoviedb.org/documentation/api) |
| Netflix Roulette | Netflix database | No | [Go!](http://netflixroulette.net/api/) |
| OMDB | Open movie database | No | [Go!](http://omdbapi.com) |
| Ron Swanson Quotes | Television | No | [Go!](https://github.com/jamesseanwright/ron-swanson-quotes#ron-swanson-quotes-api) |
| TVMaze | TV Show Data | No | [Go!](http://www.tvmaze.com/api) |
| Video download | Video download API for youtube, rai.it, mediaset.it, la7.it and hundreds of other sites. | No | [Go!](https://api.daniil.it) |
| Vimeo | Vimeo Developer API | Yes | [Go!](https://developer.vimeo.com/) |
| YouTube | Add YouTube functionality to your sites and apps. | Yes / No | [Go!](https://developers.google.com/youtube/)

### Weather

| API | Description | OAuth | Link |
|---|---|---|---|
| Dark Sky Forecast API | Weather | No, but  `apiKey` query string | [Go!](https://developer.forecast.io/) |
| OpenWeatherMap | Weather | No | [Go!](http://openweathermap.org/api) |
| Wunderground | Weather | No | [Go!](http://www.wunderground.com/weather/api/) |
| Yahoo! Weather | Weather | No | [Go!](https://developer.yahoo.com/weather/) |
